// BtClientC1.java
// Data exchange with BtServer.java
// Same as BtClientC.java, but not device inquiry, data from
// database of paired devices

import java.io.*;
import ch.aplu.bluetooth.*;
import javax.swing.JOptionPane;
import ch.aplu.util.Console;
import ch.aplu.util.ExitListener;
import javax.bluetooth.*;

public class BtClientC1 implements ExitListener
{
  // ------------- Inner class TransferThread ---------------
  private class TransferThread extends Thread
  {
    public void run()
    {
      Console.delay(2000);  // Wait until server is ready
      try
      {
        for (int n = 1; n <= 100; n++)
        {
          System.out.println("Send value: " + n);
          dos.writeInt(n);
          dos.flush();

          // Blocking, throws IOException
          // when server closes connection or BluetoothClient.disconnect() is called
          int k = dis.readInt();
          System.out.println("Reply value: " + k);
        }
        dos.writeInt(-1);  // Send disconnect notification
        dos.flush();
      }
      catch (IOException ex)
      {
        System.out.println("readInt() unblocked");
      }
      Console.delay(2000);
      bc.disconnect();
      System.out.println("Transfer thread terminated");
    }

  }
  // ------------- End of inner class -----------------------

  private final String serviceName = "BtServer";
  private BluetoothClient bc;
  private DataInputStream dis;
  private DataOutputStream dos;

  public BtClientC1()
  {
    String prompt = "Enter Server's Bluetooth Name";
    String serverName;
    do
    {
      serverName = JOptionPane.showInputDialog(null, prompt);
      if (serverName == null)
        System.exit(0);
    }
    while (serverName.trim().length() == 0);

    Console c = new Console();
    c.addExitListener(this);

    RemoteDevice rd = BluetoothFinder.searchPreknownDevice(serverName);
    if (rd == null)
      System.out.println(serverName + " not found as preknown device");
    else
      System.out.println(serverName + " found as preknown device");

    if (rd == null)
    {
      System.out.println(serverName + " need to perform Bluetooth inquiry");
      bc = new BluetoothClient(serverName, serviceName);
    }
    else
    {
      System.out.println("Retrieving info from RemoteDevice:");
      bc = new BluetoothClient(rd, serviceName);
    }
    bc.setVerbose(true);
    System.out.println("Trying to connect to '" + serverName
      + "' using service '" + serviceName + "'");
    if (!bc.connect())
    {
      System.out.println("Connection failed");
      return;
    }
    System.out.println("Connection established");
    dis = new DataInputStream(bc.getInputStream());
    dos = new DataOutputStream(bc.getOutputStream());

    new TransferThread().start();
  }

  public void notifyExit()
  {
    if (bc != null)
      bc.disconnect();
    System.exit(0);
  }

  public static void main(String[] args)
  {
    new BtClientC1();
  }

}
